==> giza_cli-0.0.2.tar.gz: giza_cli-0.0.2/README.md <==
# Giza Command Line Interface

![Logo](https://framerusercontent.com/images/dGhFEb4pIwUJ5SArbs7udVlSs.png)
[![GitHub Workflow Status](https://github.com/gizatechxyz/giza-cli/actions/workflows/onpush.yml/badge.svg)](https://github.com/gizatechxyz/giza-cli/actions/workflows/onpush.yml)
[![Project license](https://img.shields.io/github/license/gizatechxyz/orion.svg?style=flat-square)](LICENSE)
[![Pull Requests welcome](https://img.shields.io/badge/PRs-welcome-ff69b4.svg?style=flat-square)](https://github.com/gizatechxyz/orion/issues?q=is%3Aissue+is%3Aopen)
[![Join the community](https://dcbadge.vercel.app/api/server/FR3Cd88x6r?style=flat-square)](https://discord.gg/FR3Cd88x6r)
<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-1-orange.svg?style=flat-square)](#contributors-)
<!-- ALL-CONTRIBUTORS-BADGE:END -->

```text
  _______  __   ________      ___           ______  __       __
 /  _____||  | |       /     /   \         /      ||  |     |  |
|  |  __  |  | `---/  /     /  ^  \       |  ,----'|  |     |  |
|  | |_ | |  |    /  /     /  /_\  \      |  |     |  |     |  |
|  |__| | |  |   /  /----./  _____  \     |  `----.|  `----.|  |
 \______| |__|  /________/__/     \__\     \______||_______||__|

```

Welcome to Giza`s Platform CLI!

This CLI provides the utilities to interact with Giza Platform using the terminal.

**Discalimer**: this is still in an experimental stage so the functionality is subject to change.

- [Giza Command Line Interface](#giza-command-line-interface)
  - [🚀 Installation](#-installation)
    - [Recomended installation with pipx](#recomended-installation-with-pipx)
    - [Install from PyPi](#install-from-pypi)
    - [Installing from source](#installing-from-source)
  - [📚 Documentation](#-documentation)
  - [🌟 What's new](#-whats-new)
  - [🤝 Join the community!](#-join-the-community)
  - [Contributors ✨](#contributors-)
  - [License](#license)

## 🚀 Installation

### Recomended installation with pipx

[pipx](https://pypa.github.io/pipx/) allows to install the dependency in an isolated environment. With ths we can make sure that it does not conflict with any of our installed dependencies.

```bash
pipx install giza-cli
```

### Install from PyPi

For the latest release:

```bash
pip install giza-cli
```

### Installing from source

Clone the repository and install it with `pip`:

```bash
    git clone git@github.com:gizatechxyz/giza-cli.git
    cd giza-cli
    pip install .
```

Or install it directly from the repo:

```bash
  pip install git+ssh://git@github.com/gizatechxyz/giza-cli.git
```

## 📚 Documentation

You can check our official docs [here](https://giza-cli.gizatech.xyz/main).

- **Examples** includes examples on how to use the CLI functionalities.

- **Resources** brings the documentation of the different resources and actions that can be done with the CLI.

- 🧠 **Reference** for the API reference and internals of the CLI.

## 🌟 What's new

For a detailed list of changes, please refer to the [CHANGELOG](CHANGELOG.md) file.

## 🤝 Join the community!

Join the community and help build a safer and transparent AI in our [Discord](https://discord.gg/Kt24CsMb5k)!

## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tbody>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://es.linkedin.com/in/gonzalo-mellizo-soto-diaz-590260108"><img src="https://avatars.githubusercontent.com/u/18899187?v=4?s=100" width="100px;" alt="Gonzalo Mellizo"/><br /><sub><b>Gonzalo Mellizo</b></sub></a><br /><a href="https://github.com/gizatechxyz/giza-cli/commits?author=Gonmeso" title="Code">💻</a></td>
    </tr>
  </tbody>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!

## License

[MIT](https://choosealicense.com/licenses/mit/)

==> giza_cli-0.3.0.tar.gz: giza_cli-0.3.0/README.md <==
# Giza Command Line Interface

[![GitHub Workflow Status](https://github.com/gizatechxyz/giza-cli/actions/workflows/onpush.yml/badge.svg)](https://github.com/gizatechxyz/giza-cli/actions/workflows/onpush.yml)
[![Project license](https://img.shields.io/github/license/gizatechxyz/orion.svg?style=flat-square)](LICENSE)
[![Pull Requests welcome](https://img.shields.io/badge/PRs-welcome-ff69b4.svg?style=flat-square)](https://github.com/gizatechxyz/orion/issues?q=is%3Aissue+is%3Aopen)
[![Join the community](https://dcbadge.vercel.app/api/server/FR3Cd88x6r?style=flat-square)](https://discord.gg/FR3Cd88x6r)
<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-1-orange.svg?style=flat-square)](#contributors-)
<!-- ALL-CONTRIBUTORS-BADGE:END -->

```text
  _______  __   ________      ___           ______  __       __
 /  _____||  | |       /     /   \         /      ||  |     |  |
|  |  __  |  | `---/  /     /  ^  \       |  ,----'|  |     |  |
|  | |_ | |  |    /  /     /  /_\  \      |  |     |  |     |  |
|  |__| | |  |   /  /----./  _____  \     |  `----.|  `----.|  |
 \______| |__|  /________/__/     \__\     \______||_______||__|

```

Welcome to Giza CLI!

This CLI provides the utilities to interact with Giza using the terminal.

**Discalimer**: this is still in an experimental stage so the functionality is subject to change.

- [Giza Command Line Interface](#giza-command-line-interface)
  - [🚀 Installation](#-installation)
    - [Recomended installation with pipx](#recomended-installation-with-pipx)
    - [Install from PyPi](#install-from-pypi)
    - [Installing from source](#installing-from-source)
  - [📚 Documentation](#-documentation)
  - [🌟 What's new](#-whats-new)
  - [🤝 Join the community!](#-join-the-community)
  - [Contributors ✨](#contributors-)
  - [License](#license)

## 🚀 Installation

### Recomended installation with pipx

[pipx](https://pypa.github.io/pipx/) allows to install the dependency in an isolated environment. With ths we can make sure that it does not conflict with any of our installed dependencies.

```bash
pipx install giza-cli
```

### Install from PyPi

For the latest release:

```bash
pip install giza-cli
```

### Installing from source

Clone the repository and install it with `pip`:

```bash
    git clone git@github.com:gizatechxyz/giza-cli.git
    cd giza-cli
    pip install .
```

Or install it directly from the repo:

```bash
  pip install git+ssh://git@github.com/gizatechxyz/giza-cli.git
```

## 📚 Documentation

You can check our official docs [here](https://orion-giza.gitbook.io/main-1/welcome/readme).

- **Examples** includes examples on how to use the CLI functionalities.

- **Resources** brings the documentation of the different resources and actions that can be done with the CLI.

- 🧠 **Reference** for the API reference and internals of the CLI.

## 🌟 What's new

For a detailed list of changes, please refer to the [CHANGELOG](CHANGELOG.md) file.

## 🤝 Join the community!

Join the community and help build a safer and transparent AI in our [Discord](https://discord.gg/Kt24CsMb5k)!

## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tbody>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://es.linkedin.com/in/gonzalo-mellizo-soto-diaz-590260108"><img src="https://avatars.githubusercontent.com/u/18899187?v=4?s=100" width="100px;" alt="Gonzalo Mellizo"/><br /><sub><b>Gonzalo Mellizo</b></sub></a><br /><a href="https://github.com/gizatechxyz/giza-cli/commits?author=Gonmeso" title="Code">💻</a></td>
    </tr>
  </tbody>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!

## License

[MIT](https://choosealicense.com/licenses/mit/)
